@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2015-2016 -- leonerd@leonerd.org.uk
 
 package Device::Chip::MPL3115A2;
 
@@ -11,7 +11,7 @@ use base qw( Device::Chip::Base::RegisteredI2C );
 
 use utf8;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
@@ -25,6 +25,16 @@ use Data::Bitfield qw( bitfield boolfield enumfield );
 
 C<Device::Chip::MPL3115A2> - chip driver for a F<MPL3115A2>
 
+=head1 SYNOPSIS
+
+ use Device::Chip::MPL3115A2;
+
+ my $chip = Device::Chip::MPL3115A2->new;
+ $chip->mount( Device::Chip::Adapter::...->new )->get;
+
+ printf "Current pressure is %.2f kPa\n",
+    $chip->read_pressure->get;
+
 =head1 DESCRIPTION
 
 This L<Device::Chip> subclass provides specific communication to a
@@ -143,14 +153,14 @@ L<Future> instances.
 
 =head2 read_config
 
-   $config = $mpl->read_config->get
+   $config = $chip->read_config->get
 
 Returns a C<HASH> reference of the contents of control registers C<CTRL_REG1>
 to C<CTRL_REG3>, using fields named from the data sheet.
 
 =head2 change_config
 
-   $mpl->change_config( %changes )->get
+   $chip->change_config( %changes )->get
 
 Writes updates to the control registers C<CTRL_REG1> to C<CTRL_REG3>. This
 will be performed as a read-modify-write operation, so any fields not given
@@ -201,9 +211,9 @@ sub change_config
 
 =head2 set_sealevel_pressure
 
-   $pressure = $mpl->get_sealevel_pressure->get
+   $pressure = $chip->get_sealevel_pressure->get
 
-   $mpl->set_sealevel_pressure->get( $pressure )
+   $chip->set_sealevel_pressure->get( $pressure )
 
 Read or write the barometric pressure calibration register which is used to
 convert pressure to altitude when the chip is in altimeter mode, in Pascals.
@@ -222,7 +232,7 @@ sub set_sealevel_pressure {
 
 =head2 read_pressure
 
-   $pressure = $mpl->read_pressure->get
+   $pressure = $chip->read_pressure->get
 
 Returns the value of the C<OUT_P_*> registers, suitably converted into
 Pascals. (The chip must be in barometer mode and must I<not> be in C<RAW> mode
@@ -234,7 +244,7 @@ sub read_pressure { shift->_mplread_p( REG_OUT_P_MSB ) }
 
 =head2 read_altitude
 
-   $altitude = $mpl->read_altitude->get
+   $altitude = $chip->read_altitude->get
 
 Returns the value of the C<OUT_P_*> registers, suitably converted into metres.
 (The chip must be in altimeter mode and must I<not> be in C<RAW> mode for the
@@ -246,7 +256,7 @@ sub read_altitude { shift->_mplread_a( REG_OUT_P_MSB ) }
 
 =head2 read_temperature
 
-   $temperature = $mpl->read_temperature->get
+   $temperature = $chip->read_temperature->get
 
 Returns the value of the C<OUT_T_*> registers, suitable converted into degrees
 C. (The chip must I<not> be in C<RAW> mode for the conversion to work).
@@ -259,9 +269,9 @@ sub read_temperature { shift->_mplread_t( REG_OUT_T_MSB ) }
 
 =head2 read_max_pressure
 
-   $pressure = $mpl->read_min_pressure->get
+   $pressure = $chip->read_min_pressure->get
 
-   $pressure = $mpl->read_max_pressure->get
+   $pressure = $chip->read_max_pressure->get
 
 Returns the values of the C<P_MIN> and C<P_MAX> registers, suitably converted
 into Pascals.
@@ -270,9 +280,9 @@ into Pascals.
 
 =head2 clear_max_pressure
 
-   $mpl->clear_min_pressure->get
+   $chip->clear_min_pressure->get
 
-   $mpl->clear_max_pressure->get
+   $chip->clear_max_pressure->get
 
 Clear the C<P_MIN> or C<P_MAX> registers, resetting them to start again from
 the next measurement.
@@ -289,9 +299,9 @@ sub clear_max_pressure { shift->write_reg( REG_P_MAX_MSB, "\x00\x00\x00" ) }
 
 =head2 read_max_altitude
 
-   $altitude = $mpl->read_min_altitude->get
+   $altitude = $chip->read_min_altitude->get
 
-   $altitude = $mpl->read_max_altitude->get
+   $altitude = $chip->read_max_altitude->get
 
 Returns the values of the C<P_MIN> and C<P_MAX> registers, suitably converted
 into metres.
@@ -302,9 +312,9 @@ into metres.
 
 =head2 clear_max_altitude
 
-   $mpl->clear_min_altitude->get
+   $chip->clear_min_altitude->get
 
-   $mpl->clear_max_altitude->get
+   $chip->clear_max_altitude->get
 
 Clear the C<P_MIN> or C<P_MAX> registers, resetting them to start again from
 the next measurement.
@@ -321,9 +331,9 @@ sub read_max_altitude { shift->_mplread_a( REG_P_MAX_MSB ) }
 
 =head2 read_max_temperature
 
-   $temperature = $mpl->read_min_temperature->get
+   $temperature = $chip->read_min_temperature->get
 
-   $temperature = $mpl->read_max_temperature->get
+   $temperature = $chip->read_max_temperature->get
 
 Returns the values of the C<T_MIN> and C<T_MAX> registers, suitably converted
 into metres.
@@ -332,9 +342,9 @@ into metres.
 
 =head2 clear_max_temperature
 
-   $mpl->clear_min_temperature->get
+   $chip->clear_min_temperature->get
 
-   $mpl->clear_max_temperature->get
+   $chip->clear_max_temperature->get
 
 Clear the C<T_MIN> or C<T_MAX> registers, resetting them to start again from
 the next measurement.
@@ -353,7 +363,7 @@ sub clear_max_temperature { shift->write_reg( REG_T_MAX_MSB, "\x00\x00" ) }
 
 =head2 check_id
 
-   $mpl->check_id->get
+   $chip->check_id->get
 
 Reads the C<WHO_AM_I> register and checks for a valid ID result. The returned
 future fails if the expected result is not received.
@@ -377,7 +387,7 @@ sub check_id
 
 =head2 start_oneshot
 
-   $mpl->start_oneshot->get
+   $chip->start_oneshot->get
 
 Sets the C<OST> bit of C<CTRL_REG1> to start a one-shot measurement when in
 standby mode. After calling this method you will need to use
@@ -399,7 +409,7 @@ sub start_oneshot
 
 =head2 busywait_oneshot
 
-   $mpl->busywait_oneshot->get
+   $chip->busywait_oneshot->get
 
 Repeatedly reads the C<OST> bit of C<CTRL_REG1> until it becomes clear.
 
@@ -418,7 +428,7 @@ sub busywait_oneshot
 
 =head2 oneshot
 
-   $mpl->oneshot->get
+   $chip->oneshot->get
 
 A convenient wrapper around C<start_oneshot> and C<busywait_oneshot>.
 
